<?php
require('Smarty/Smarty.class.php');

/**
 * A smarty wrapper for the view controller of zend.
 * 
 * @author Nophinity
 * @version 1.0.9
 *
 */
class Custom_Smarty extends Smarty {

    protected $mainPage;
    protected $templateFile;
    protected $masterTemplate;
    protected $webRoot;
    protected $theme;
    protected $secundaryMenu;
    protected $debugText = array();

    /**
     * Loads the template
     *
     * @param string $mainPage
     * @param string $templateFile
     * @param string $masterTemplate
     * @param string $secundaryMenu
     */
    
    function clearstring($string) {
    return implode(" ;",explode(';', $string));
}
    
    function __construct($mainPage, $templateFile, $masterTemplate="mainTemplate.tpl", $secundaryMenu=NULL) {
        $this->Smarty();
        $this->register_modifier('sslash', 'stripslashes');
        
        $this->webRoot	= Zend::registry('siteConfig')->webRoot;
        $this->theme	= Zend::registry('siteConfig')->theme;

        $this->template_dir	= $this->webRoot . "/themes/" . $this->theme;
        $this->compile_dir	= $this->webRoot . "/misc";

        $this->templateFile	= $templateFile;
        $this->masterTemplate = $masterTemplate;
        $this->mainPage = $mainPage;

        $this->secundaryMenu = $secundaryMenu;
        
        $LangString = Language::toArray(true);

        $mainMenu = array(
        "$LangString[tasks]"     => "tasks",
        "$LangString[computers]" => "computers",
        "$LangString[reports]"   => "reports",
        "$LangString[tools]"     => "tools",
        "$LangString[options]"   => "options",
        "$LangString[help]"      => "help"
        );
        $this->assign('ls', $LangString);
        
        $this->assign('mainMenu', $mainMenu);
        $this->assign('lang', $_SESSION['lang']);
        $this->assign('contentTemplate', $this->templateFile);
        $this->assign('theme', $this->theme);
        $this->assign('mainPage', $this->mainPage);

        if ($this->secundaryMenu != NULL) {
            $this->assign('hasSecMenu', true);
            $this->assign('secundaryMenu', "submenus/" . $this->secundaryMenu);
        }

        $siteConfig = Zend::registry('siteConfig');
        if ($siteConfig->debugMode == "box") {
            $this->assign("debugBox", true);
        }
        $sparseurl = explode('/', $siteConfig->fullUrl,4);
        $fullurl = $sparseurl[3]===""?'/':'/'.$sparseurl[3];

        $this->assign('fullUrl', $fullurl);
        $this->assign('fullURL', $fullurl);        
        $this->assign('assetUrl', $fullurl . "themes/" . $this->theme . '/' );
        
        $implTask = new Custom_ComputerSelect();
        $this->register_function('getUserTasks', array(&$implTask, "smartyGetUserTasks"));
        $this->register_function('getTasksChildren', array(&$implTask, 'smartyGetTasksChildren'));
        $this->register_function('getTasksRunning', array(&$implTask, 'smartyGetTasksRunning'));
        $this->register_function('searchArray', array(&$implTask, 'smartyArraySearch'));
        $this->register_function('getComputerName', array(&$implTask, 'smartyGetComputerName'));
        $this->register_function('getComputerStatus', array(&$implTask, 'smartyGetComputerStatus'));
        $this->register_modifier('separateString', array(&$implTask, 'smartySeparateString'));
                
    }

    /**
     * Displays the template
     *
     */
    function dumpT() {
        $this->assign('debugText', Custom_Debug::$debugText);
        $this->display($this->masterTemplate);
    }

    /**
     * Fetches and returns the template
     *
     * @return smarty_template
     */
    function fetchT() {
        return $this->fetch($this->masterTemplate);
    }
}